Summary:       An interactive computing environment for Python 
Name:          ipython
Version:       3.2.2
Release:       %mkrel 1
Source0:       http://pypi.python.org/packages/source/i/ipython/%{name}-%{version}.tar.xz
License:       BSD
Group:         Development/Python
Url:           http://ipython.org
BuildArch:     noarch
Requires:      python-pexpect >= 2.2
Requires:      python-mglob
Requires:      python-simplegeneric
Recommends:      python-mpi4py
Recommends:      wxPython, python-qt4, pyside >= 1.0.3
Recommends:      python-pygments 
Recommends:      python-pyzmq >= 2.1.11
Recommends:      python-tornado >= 3.1 
Recommends:      python-jinja2
Recommends:      python-matplotlib
Recommends:      python-jsonschema
Recommends:      python-terminado

BuildRequires: python-devel
BuildRequires: python-simplegeneric
BuildRequires: python-setuptools
BuildRequires: python-pygments
BuildRequires: python-sphinx 
BuildRequires: python-jinja2
BuildRequires: python-pyzmq >= 2.1.11
BuildRequires: python-pexpect >= 2.2
BuildRequires: python-tornado >= 4.0
BuildRequires: python-matplotlib
BuildRequires: python-numpydoc
BuildRequires: %{_lib}girepository-devel

%package -n python3-ipython
Group:         Development/Python
Summary:       An enhanced interactive Python shell
BuildRequires: python3-devel
BuildRequires: python3-setuptools
BuildRequires: python3-simplegeneric
BuildRequires: python3-pygments
BuildRequires: python3-sphinx 
BuildRequires: python3-jinja2
BuildRequires: python3-pexpect
BuildRequires: python3-pyzmq
BuildRequires: python3-tornado >= 4.0 
Requires:      python3-pexpect
Requires:      python3-mglob
Requires:      python3-simplegeneric
Recommends:      python3-pygments
Recommends:      python3-sip
Recommends:      python3-qt4
Recommends:      python3-mpi4py
Recommends:      python3-tornado 
Recommends:      python3-jinja2
Recommends:      python3-matplotlib
Recommends:      python3-pyzmq
Recommends:      python3-jsonschema
Recommends:      python3-terminado

%description
The goal of IPython is to create a comprehensive environment for
interactive and exploratory computing. To support this goal, IPython
has two main components:

* An enhanced interactive Python shell.
* An architecture for interactive parallel computing.

The enhanced interactive Python shell has the following main features:

* Comprehensive object introspection.
* Input history, persistent across sessions.
* Caching of output results during a session with automatically
  generated references.
* Readline based name completion.
* Extensible system of 'magic' commands for controlling the
  environment and performing many tasks related either to IPython or
  the operating system.
* Configuration system with easy switching between different setups
  (simpler than changing $PYTHONSTARTUP environment variables every
  time).
* Session logging and reloading.
* Extensible syntax processing for special purpose situations.
* Access to the system shell with user-extensible alias system.
* Easily embeddable in other Python programs and wxPython GUIs.
* Integrated access to the pdb debugger and the Python profiler.

The parallel computing architecture has the following main features:

* Quickly parallelize Python code from an interactive Python/IPython
  session.
* A flexible and dynamic process model that be deployed on anything
  from multicore workstations to supercomputers.
* An architecture that supports many different styles of parallelism,
  from message passing to task farming.
* Both blocking and fully asynchronous interfaces.
* High level APIs that enable many things to be parallelized in a few
  lines of code.
* Share live parallel jobs with other users securely.
* Dynamically load balanced task farming system.  
* Robust error handling in parallel code.

%description -n python3-ipython
IPython provides a replacement for the interactive Python interpreter with
extra functionality.

Main features:
 * Comprehensive object introspection.
 * Input history, persistent across sessions.
 * Caching of output results during a session with automatically generated\
   references.
 * Readline based name completion.
 * Extensible system of 'magic' commands for controlling the environment and
   performing many tasks related either to IPython or the operating system.
 * Configuration system with easy switching between different setups (simpler
   than changing $PYTHONSTARTUP environment variables every time).
 * Session logging and reloading.
 * Extensible syntax processing for special purpose situations.
 * Access to the system shell with user-extensible alias system.
 * Easily embeddable in other Python programs.
 * Integrated access to the pdb debugger and the Python profiler.

%package doc
Summary:       An Enhanced Interactive Python Shell documentation
Group:         Documentation

%description doc
IPython provides a replacement for the interactive python (Python)
interpreter with extra functionality.

This package contains comprehensive documentation for IPython in
html format, as well as examples of usage.

%prep
%setup -q
# delete bundling libs
pushd IPython/external

# use decorators of numpy
rm decorators/_decorators.py

# other packages exist in Mageia
rm simplegeneric/_simplegeneric.py
rm pexpect/_pexpect.py

popd

# Get rid of library shebangs
find . -type f -name "*.py" -exec sed -i '/#!\/usr\/bin\/env/d' {} \;

cp -a . %{py3dir}

%build
pushd %{py3dir}
%{__python3} setup.py build
popd

%{__python} setup.py build

%install
rm -rf %buildroot
pushd %{py3dir}
%{__python3} setup.py install -O1 --skip-build --root %{buildroot} 
rm %{buildroot}%{_bindir}/ipython
rm %{buildroot}%{_bindir}/ipcluster
rm %{buildroot}%{_bindir}/ipcontroller
rm %{buildroot}%{_bindir}/ipengine
rm %{buildroot}%{_bindir}/iptest

popd

%{__python} setup.py install -O1 --skip-build --root %{buildroot}

chmod 644 %{buildroot}%{_mandir}/man1/*.1*
find %{buildroot} -name .buildinfo -exec rm -f {} \;
find %{buildroot} -name .git_commit_info.ini -exec rm -rf {} \;

%files
%{_bindir}/ipython
%{_bindir}/ipcluster
%{_bindir}/ipcontroller
%{_bindir}/ipengine
%{_bindir}/iptest
%{_bindir}/ipython2
%{_bindir}/ipcluster2
%{_bindir}/ipcontroller2
%{_bindir}/ipengine2
%{_bindir}/iptest2

%{python_sitelib}/*

%files doc
%doc examples 
%{_mandir}/man1/*

%files -n python3-ipython 
%{_bindir}/ipython3
%{_bindir}/ipcluster3
%{_bindir}/ipcontroller3
%{_bindir}/ipengine3
%{_bindir}/iptest3

%{python3_sitelib}/*


%changelog
* Sun Mar 20 2016 bb <bb> 3.2.2-1pclos2016
- update
